package net.outlyer.plugins;

/*
 * Copyright (c) 2008, Toni Corvera. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import java.io.File;
import net.outlyer.plugins.utils.*;

/**
 * Sample shell for tests, files passed as arguments will be loaded and
 * executed.
 */
public final class Shell {
    public static void main(String...args) {
        if (args.length == 0) {
            System.err.printf("Usage: java [...] %s [file1.js [file2.js [...]]]\n",
                              Shell.class.getName());
            System.exit(1);
        }
        
        final PluginEnvironment pe = PluginEnvironment.create();
        pe.exportGlobalObject("input", new Input());
        pe.exportGlobalObject("out", new Output());
        pe.exportGlobalObject("err", new Output(System.err));
        pe.exportGlobalObject("hooks", new Hooks());
        // Generally either UI or GUI should be used but not both
        // since GUI falls-back to UI if appropriate
        pe.exportGlobalObject("ui", new UI());
        pe.exportGlobalObject("gui", new GUI());
        final PluginObject po = new PluginObject();
        pe.setPluginObject(po);
        
        for (final String path : args) {
            try {
                final Sandbox sandbox = pe.createSandbox(new File(path).toURI());
                sandbox.execute();
            }
            catch (final PluginException e) {
                System.err.printf("Exception while running plugin %s: %s\n",
                                  path, e.getLocalizedMessage());
                System.exit(2);
            }
        }
    }
}
