package net.outlyer.plugins.utils;

/*
 * Copyright (c) 2008, Toni Corvera. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
 * FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA,
 * OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

import java.io.File;

/**
 * User Interface-related methods.
 */
public class UI {
    /**
     * Prompt the user for a string
     * @param question Question to ask
     * @return String written by the user
     */
    public String prompt(final String question) {
        System.err.printf("%s: ", question);
        return new Input().readline();
    }

    /**
     * Prompts the user for an existent file path.
     * If the provided path is empty the result will be null, otherwise
     * the prompt will be repeated until a valid file is provided.
     * @param message Message to display
     * @return User-provided file or null if none
     */
    public File promptForFile(final String message) {
        do {
            final Input in = new Input();
            System.err.printf("%s: ", message);
            final String path = in.readline();
            if (path.isEmpty()) {
                return null;
            }
            final File file = new File(path);
            if (file.isFile()) {
                return file;
            }
        } while (true);
    }
}
